#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os

from tvm.commands import base
from tvm.shared.io import info
from tvm.helpers.generate import GenerateHelper


class GenerateCommand(base.BaseCommand):
    def __init__(self, **arguments):
        super(self.__class__, self).__init__(**dict(arguments, **{'_ignore_errors': True}))

        self.helper = GenerateHelper(self.config, self.collection)
        self._extact_args(arguments)
        self._exec()

    def _extact_args(self, arguments):
        self._path = os.path.abspath(os.path.expanduser(arguments['<path>']))
        self._append = arguments.get('--append', False)
        self._force = arguments.get('--force', False)

    def _exec(self):
        records = self.helper.load_stored_files(self._path, force_add=self._force)
        if not records:
            return info('No new records were found.')

        self.helper.print_records(records)
        if not self._append:
            return info('%d new records were found. `--append` to add to records.' % len(records))

        self.collection.save(records)
        info('New entries recorded: %d (%d total).' % (len(records),
                                                       len(self.collection.entries) + len(records)))
