#!/usr/bin/env python
# -*- coding: utf-8 -*-
from tvm.commands import base
from tvm.helpers.ls import LsHelper
from tvm.shared.io import print_matched_status
from tvm.shared.io import err


class LsCommand(base.BaseCommand):
    def __init__(self, **arguments):
        super(self.__class__, self).__init__(**dict(arguments, **{'_ignore_errors': True}))

        self.helper = LsHelper(self.config, self.collection)
        self._extact_args(arguments)
        self._exec()

    def _extact_args(self, arguments):
        self._search_query = '_'.join(arguments.get('<title>', []))
        self._expand = arguments.get('--expand', False)
        self._filter_type = arguments.get('--filter', None)

        VALID_FILTERS = ['recorded', 'nrecorded', 'new']
        if self._filter_type and self._filter_type not in VALID_FILTERS:
            err('Unexpected filter: "%s". tvm --help for info.' % self._filter_type)
            exit(0)

    def _exec(self):
        if not self._search_query:
            generated_table = self.helper.generate_table(filter_type=self._filter_type)
            return self.helper.print_table(generated_table)

        # ls <title>... (specific show title).
        matched = self.collection.find_matching_titles(self._search_query)
        print_matched_status(matched)

        generated_tree = self.helper.generate_tree(matched, expand=self._expand)
        self.helper.print_tree(generated_tree, matched)
