#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import time

from datetime import datetime

from tvm.helpers import base
from tvm.shared.io import err, info, info2


class GenerateHelper(base.BaseHelper):
    def __init__(self, config, collection):
        super(self.__class__, self).__init__(config, collection)

    def _created_datetime(self, path):
        mask = '%a %b %d %H:%M:%S %Y'
        return datetime.strptime(time.ctime(os.path.getmtime(path)), mask)

    def load_stored_files(self, path, force_add=False):
        """ Set `force_add=True` to include a found entry even if it has already
            been recorded.
        """
        if not os.path.exists(path) or not os.path.isdir(path):
            err('<path> must be an existing directory.')
            exit(0)

        if not os.listdir(path):
            info('No potential records were found in "%s".' % path)
            exit(0)

        new_records = []
        for dirname, _, filenames in os.walk(path):
            for filename in filenames:
                if filename.startswith('.'):
                    continue

                path = os.path.join(dirname, filename)
                episode, ext = os.path.splitext(filename)
                title, season = os.path.split(dirname)

                # The title might be like x/y/title so we need to fix that.
                title = os.path.basename(title)

                # Don't add it if it has already been recorded.
                if (season, episode, title) in self.collection.entries and not force_add:
                    continue

                created_datetime = self._created_datetime(path)
                new_records.append((created_datetime, season, episode, title))

        return new_records

    def print_records(self, records):
        info('These are the records generated:')
        for record in records:
            info2(self.collection.record_to_csv([record]))
