#!/usr/bin/env python
# -*- coding: utf-8 -*-
""" Proxy over ffprobe to retrieve data about episode video files. """
import subprocess
import json
import shlex
import os
import datetime


class VideoSource(object):
    COMMAND = 'ffprobe -v quiet -print_format json -show_format -show_streams'

    @staticmethod
    def all(episode_path):
        """ The `episode_path` must be an absolute path. Returns a dictionary of all
            values retrieved from ffprobe.

            An empty dictionary is returned if `episode_path` does not exist or is
            not a file.
        """
        if not os.path.isfile(episode_path):
            return {}

        command = shlex.split(VideoSource.COMMAND) + [episode_path]
        process = subprocess.Popen(command,
                                   stdout=subprocess.PIPE,
                                   stderr=subprocess.PIPE)

        stdout, _ = process.communicate()
        return json.loads(stdout)

    @staticmethod
    def is_video(episode_path):
        """ True if `episode_path` is a video file, False otherwise. """
        return bool(VideoSource.all(episode_path))

    @staticmethod
    def duration(episode_path):
        """ Returns a timedelta object containing the duration of the episode.

            @see VideoSource.all
        """
        duration = VideoSource.all(episode_path)['format']['duration']
        return datetime.timedelta(seconds=float(duration))
